# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.o_auth_connection_api import OAuthConnectionApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestOAuthConnectionApi(unittest.TestCase):
    """OAuthConnectionApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.o_auth_connection_api.OAuthConnectionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_o_auth_connection(self):
        """Test case for create_o_auth_connection

        Create an OAuth connection  # noqa: E501
        """
        pass

    def test_exchange_authorization_token_and_create_or_update_inbox(self):
        """Test case for exchange_authorization_token_and_create_or_update_inbox

        Exchange authorization code for access token and create inbox  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
