# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.connector_controller_api import ConnectorControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestConnectorControllerApi(unittest.TestCase):
    """ConnectorControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.connector_controller_api.ConnectorControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_connector(self):
        """Test case for create_connector

        Create an inbox connector  # noqa: E501
        """
        pass

    def test_create_connector_imap_connection(self):
        """Test case for create_connector_imap_connection

        Create an inbox connector IMAP connection  # noqa: E501
        """
        pass

    def test_create_connector_smtp_connection(self):
        """Test case for create_connector_smtp_connection

        Create an inbox connector SMTP connection  # noqa: E501
        """
        pass

    def test_create_connector_sync_settings(self):
        """Test case for create_connector_sync_settings

        Create an inbox connector sync settings  # noqa: E501
        """
        pass

    def test_create_connector_with_options(self):
        """Test case for create_connector_with_options

        Create an inbox connector with options  # noqa: E501
        """
        pass

    def test_delete_all_connector(self):
        """Test case for delete_all_connector

        Delete all inbox connectors  # noqa: E501
        """
        pass

    def test_delete_connector(self):
        """Test case for delete_connector

        Delete an inbox connector  # noqa: E501
        """
        pass

    def test_delete_connector_imap_connection(self):
        """Test case for delete_connector_imap_connection

        Delete an inbox connector IMAP connection  # noqa: E501
        """
        pass

    def test_delete_connector_smtp_connection(self):
        """Test case for delete_connector_smtp_connection

        Delete an inbox connector SMTP connection  # noqa: E501
        """
        pass

    def test_delete_connector_sync_settings(self):
        """Test case for delete_connector_sync_settings

        Create an inbox connector sync settings  # noqa: E501
        """
        pass

    def test_get_all_connector_events(self):
        """Test case for get_all_connector_events

        Get all inbox connector events  # noqa: E501
        """
        pass

    def test_get_connector(self):
        """Test case for get_connector

        Get an inbox connector  # noqa: E501
        """
        pass

    def test_get_connector_by_email_address(self):
        """Test case for get_connector_by_email_address

        Get connector by email address  # noqa: E501
        """
        pass

    def test_get_connector_by_inbox_id(self):
        """Test case for get_connector_by_inbox_id

        Get connector by inbox ID  # noqa: E501
        """
        pass

    def test_get_connector_by_name(self):
        """Test case for get_connector_by_name

        Get connector by name  # noqa: E501
        """
        pass

    def test_get_connector_event(self):
        """Test case for get_connector_event

        Get an inbox connector event  # noqa: E501
        """
        pass

    def test_get_connector_events(self):
        """Test case for get_connector_events

        Get an inbox connector events  # noqa: E501
        """
        pass

    def test_get_connector_imap_connection(self):
        """Test case for get_connector_imap_connection

        Get an inbox connector IMAP connection  # noqa: E501
        """
        pass

    def test_get_connector_provider_settings(self):
        """Test case for get_connector_provider_settings

        Get SMTP and IMAP connection settings for common mail providers  # noqa: E501
        """
        pass

    def test_get_connector_smtp_connection(self):
        """Test case for get_connector_smtp_connection

        Get an inbox connector SMTP connection  # noqa: E501
        """
        pass

    def test_get_connector_sync_settings(self):
        """Test case for get_connector_sync_settings

        Get an inbox connector sync settings  # noqa: E501
        """
        pass

    def test_get_connectors(self):
        """Test case for get_connectors

        Get inbox connectors  # noqa: E501
        """
        pass

    def test_send_email_from_connector(self):
        """Test case for send_email_from_connector

        Send from an inbox connector  # noqa: E501
        """
        pass

    def test_sync_connector(self):
        """Test case for sync_connector

        Sync an inbox connector  # noqa: E501
        """
        pass

    def test_test_connector_imap_connection(self):
        """Test case for test_connector_imap_connection

        Test an inbox connector IMAP connection  # noqa: E501
        """
        pass

    def test_test_connector_imap_connection_options(self):
        """Test case for test_connector_imap_connection_options

        Test an inbox connector IMAP connection options  # noqa: E501
        """
        pass

    def test_test_connector_smtp_connection(self):
        """Test case for test_connector_smtp_connection

        Test an inbox connector SMTP connection  # noqa: E501
        """
        pass

    def test_test_connector_smtp_connection_options(self):
        """Test case for test_connector_smtp_connection_options

        Test an inbox connector SMTP connection options  # noqa: E501
        """
        pass

    def test_update_connector(self):
        """Test case for update_connector

        Update an inbox connector  # noqa: E501
        """
        pass

    def test_update_connector_imap_connection(self):
        """Test case for update_connector_imap_connection

        Update an inbox connector IMAP connection  # noqa: E501
        """
        pass

    def test_update_connector_smtp_connection(self):
        """Test case for update_connector_smtp_connection

        Update an inbox connector SMTP connection  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
