# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.sent_emails_controller_api import SentEmailsControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestSentEmailsControllerApi(unittest.TestCase):
    """SentEmailsControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.sent_emails_controller_api.SentEmailsControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_all_sent_emails(self):
        """Test case for delete_all_sent_emails

        Delete all sent email receipts  # noqa: E501
        """
        pass

    def test_delete_sent_email(self):
        """Test case for delete_sent_email

        Delete sent email receipt  # noqa: E501
        """
        pass

    def test_get_all_sent_tracking_pixels(self):
        """Test case for get_all_sent_tracking_pixels

        """
        pass

    def test_get_raw_sent_email_contents(self):
        """Test case for get_raw_sent_email_contents

        Get raw sent email string. Returns unparsed raw SMTP message with headers and body.  # noqa: E501
        """
        pass

    def test_get_raw_sent_email_json(self):
        """Test case for get_raw_sent_email_json

        Get raw sent email in JSON. Unparsed SMTP message in JSON wrapper format.  # noqa: E501
        """
        pass

    def test_get_sent_delivery_status(self):
        """Test case for get_sent_delivery_status

        """
        pass

    def test_get_sent_delivery_statuses(self):
        """Test case for get_sent_delivery_statuses

        """
        pass

    def test_get_sent_delivery_statuses_by_sent_id(self):
        """Test case for get_sent_delivery_statuses_by_sent_id

        """
        pass

    def test_get_sent_email(self):
        """Test case for get_sent_email

        Get sent email receipt  # noqa: E501
        """
        pass

    def test_get_sent_email_html_content(self):
        """Test case for get_sent_email_html_content

        Get sent email HTML content  # noqa: E501
        """
        pass

    def test_get_sent_email_preview_ur_ls(self):
        """Test case for get_sent_email_preview_ur_ls

        Get sent email URL for viewing in browser or downloading  # noqa: E501
        """
        pass

    def test_get_sent_email_tracking_pixels(self):
        """Test case for get_sent_email_tracking_pixels

        """
        pass

    def test_get_sent_emails(self):
        """Test case for get_sent_emails

        Get all sent emails in paginated form  # noqa: E501
        """
        pass

    def test_get_sent_emails_with_queue_results(self):
        """Test case for get_sent_emails_with_queue_results

        Get results of email sent with queues in paginated form  # noqa: E501
        """
        pass

    def test_get_sent_organization_emails(self):
        """Test case for get_sent_organization_emails

        """
        pass

    def test_wait_for_delivery_statuses(self):
        """Test case for wait_for_delivery_statuses

        """
        pass


if __name__ == '__main__':
    unittest.main()
