# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.bounce_controller_api import BounceControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestBounceControllerApi(unittest.TestCase):
    """BounceControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.bounce_controller_api.BounceControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_filter_bounced_recipient(self):
        """Test case for filter_bounced_recipient

        Filter a list of email recipients and remove those who have bounced  # noqa: E501
        """
        pass

    def test_get_account_bounce_block_status(self):
        """Test case for get_account_bounce_block_status

        Can account send email  # noqa: E501
        """
        pass

    def test_get_bounced_email(self):
        """Test case for get_bounced_email

        Get a bounced email.  # noqa: E501
        """
        pass

    def test_get_bounced_emails(self):
        """Test case for get_bounced_emails

        Get paginated list of bounced emails.  # noqa: E501
        """
        pass

    def test_get_bounced_recipient(self):
        """Test case for get_bounced_recipient

        Get a bounced email.  # noqa: E501
        """
        pass

    def test_get_bounced_recipients(self):
        """Test case for get_bounced_recipients

        Get paginated list of bounced recipients.  # noqa: E501
        """
        pass

    def test_get_complaint(self):
        """Test case for get_complaint

        Get complaint  # noqa: E501
        """
        pass

    def test_get_complaints(self):
        """Test case for get_complaints

        Get paginated list of complaints.  # noqa: E501
        """
        pass

    def test_get_list_unsubscribe_recipients(self):
        """Test case for get_list_unsubscribe_recipients

        Get paginated list of unsubscribed recipients.  # noqa: E501
        """
        pass

    def test_get_reputation_items(self):
        """Test case for get_reputation_items

        Get paginated list of reputation items.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
