# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.phone_controller_api import PhoneControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestPhoneControllerApi(unittest.TestCase):
    """PhoneControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.phone_controller_api.PhoneControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_emergency_address(self):
        """Test case for create_emergency_address

        Create an emergency address  # noqa: E501
        """
        pass

    def test_create_phone_number(self):
        """Test case for create_phone_number

        Add phone number to your account. Only works if you have already added a plan and an initial phone number in your account and acknowledged the pricing and terms of service by enabling API phone creation.  # noqa: E501
        """
        pass

    def test_delete_emergency_address(self):
        """Test case for delete_emergency_address

        Delete an emergency address  # noqa: E501
        """
        pass

    def test_delete_phone_number(self):
        """Test case for delete_phone_number

        Delete a phone number  # noqa: E501
        """
        pass

    def test_get_all_phone_message_threads(self):
        """Test case for get_all_phone_message_threads

        Get the latest messages for all phones  # noqa: E501
        """
        pass

    def test_get_consent_status(self):
        """Test case for get_consent_status

        Get consent status  # noqa: E501
        """
        pass

    def test_get_emergency_address(self):
        """Test case for get_emergency_address

        Get an emergency address  # noqa: E501
        """
        pass

    def test_get_emergency_addresses(self):
        """Test case for get_emergency_addresses

        Get emergency addresses  # noqa: E501
        """
        pass

    def test_get_phone_message_thread_items(self):
        """Test case for get_phone_message_thread_items

        Get messages in a phone thread  # noqa: E501
        """
        pass

    def test_get_phone_message_threads(self):
        """Test case for get_phone_message_threads

        Get the latest message preview for a thread  # noqa: E501
        """
        pass

    def test_get_phone_number(self):
        """Test case for get_phone_number

        Get a phone number by ID  # noqa: E501
        """
        pass

    def test_get_phone_number_by_name(self):
        """Test case for get_phone_number_by_name

        Get a phone number by name  # noqa: E501
        """
        pass

    def test_get_phone_number_by_phone_number(self):
        """Test case for get_phone_number_by_phone_number

        Get a phone number by phone number  # noqa: E501
        """
        pass

    def test_get_phone_numbers(self):
        """Test case for get_phone_numbers

        Get phone numbers  # noqa: E501
        """
        pass

    def test_get_phone_plans(self):
        """Test case for get_phone_plans

        Get phone plans  # noqa: E501
        """
        pass

    def test_get_phone_plans_availability(self):
        """Test case for get_phone_plans_availability

        Get phone plans availability  # noqa: E501
        """
        pass

    def test_get_sent_sms_by_phone_number(self):
        """Test case for get_sent_sms_by_phone_number

        List sent TXT messages for a phone number  # noqa: E501
        """
        pass

    def test_get_sms_by_phone_number(self):
        """Test case for get_sms_by_phone_number

        List SMS messages for a phone number  # noqa: E501
        """
        pass

    def test_send_sms_from_phone_number(self):
        """Test case for send_sms_from_phone_number

        Send TXT message from a phone number  # noqa: E501
        """
        pass

    def test_set_consent_status(self):
        """Test case for set_consent_status

        Set consent status  # noqa: E501
        """
        pass

    def test_set_phone_favourited(self):
        """Test case for set_phone_favourited

        Set phone favourited state  # noqa: E501
        """
        pass

    def test_test_phone_number_send_sms(self):
        """Test case for test_phone_number_send_sms

        Test sending an SMS to a number  # noqa: E501
        """
        pass

    def test_update_phone_number(self):
        """Test case for update_phone_number

        Update a phone number  # noqa: E501
        """
        pass

    def test_validate_phone_number(self):
        """Test case for validate_phone_number

        Verify validity of a phone number  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
