# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class OptInConsentOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'email_address': 'str',
        'company_name': 'str',
        'send_opt_in_options': 'SendOptInConsentEmailOptions'
    }

    attribute_map = {
        'email_address': 'emailAddress',
        'company_name': 'companyName',
        'send_opt_in_options': 'sendOptInOptions'
    }

    def __init__(self, email_address=None, company_name=None, send_opt_in_options=None, local_vars_configuration=None):  # noqa: E501
        """OptInConsentOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._email_address = None
        self._company_name = None
        self._send_opt_in_options = None
        self.discriminator = None

        self.email_address = email_address
        if company_name is not None:
            self.company_name = company_name
        if send_opt_in_options is not None:
            self.send_opt_in_options = send_opt_in_options

    @property
    def email_address(self):
        """Gets the email_address of this OptInConsentOptions.  # noqa: E501


        :return: The email_address of this OptInConsentOptions.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this OptInConsentOptions.


        :param email_address: The email_address of this OptInConsentOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and email_address is None:  # noqa: E501
            raise ValueError("Invalid value for `email_address`, must not be `None`")  # noqa: E501

        self._email_address = email_address

    @property
    def company_name(self):
        """Gets the company_name of this OptInConsentOptions.  # noqa: E501


        :return: The company_name of this OptInConsentOptions.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this OptInConsentOptions.


        :param company_name: The company_name of this OptInConsentOptions.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def send_opt_in_options(self):
        """Gets the send_opt_in_options of this OptInConsentOptions.  # noqa: E501


        :return: The send_opt_in_options of this OptInConsentOptions.  # noqa: E501
        :rtype: SendOptInConsentEmailOptions
        """
        return self._send_opt_in_options

    @send_opt_in_options.setter
    def send_opt_in_options(self, send_opt_in_options):
        """Sets the send_opt_in_options of this OptInConsentOptions.


        :param send_opt_in_options: The send_opt_in_options of this OptInConsentOptions.  # noqa: E501
        :type: SendOptInConsentEmailOptions
        """

        self._send_opt_in_options = send_opt_in_options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptInConsentOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OptInConsentOptions):
            return True

        return self.to_dict() != other.to_dict()
