# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ImapServerSearchOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'seq_num': 'str',
        'uid': 'str',
        'since': 'datetime',
        'before': 'datetime',
        'sent_since': 'datetime',
        'sent_before': 'datetime',
        'header': 'dict(str, list[str])',
        'body': 'list[str]',
        'text': 'list[str]',
        'with_flags': 'list[str]',
        'without_flags': 'list[str]'
    }

    attribute_map = {
        'seq_num': 'seqNum',
        'uid': 'uid',
        'since': 'since',
        'before': 'before',
        'sent_since': 'sentSince',
        'sent_before': 'sentBefore',
        'header': 'header',
        'body': 'body',
        'text': 'text',
        'with_flags': 'withFlags',
        'without_flags': 'withoutFlags'
    }

    def __init__(self, seq_num=None, uid=None, since=None, before=None, sent_since=None, sent_before=None, header=None, body=None, text=None, with_flags=None, without_flags=None, local_vars_configuration=None):  # noqa: E501
        """ImapServerSearchOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._seq_num = None
        self._uid = None
        self._since = None
        self._before = None
        self._sent_since = None
        self._sent_before = None
        self._header = None
        self._body = None
        self._text = None
        self._with_flags = None
        self._without_flags = None
        self.discriminator = None

        self.seq_num = seq_num
        self.uid = uid
        self.since = since
        self.before = before
        self.sent_since = sent_since
        self.sent_before = sent_before
        self.header = header
        self.body = body
        self.text = text
        self.with_flags = with_flags
        self.without_flags = without_flags

    @property
    def seq_num(self):
        """Gets the seq_num of this ImapServerSearchOptions.  # noqa: E501


        :return: The seq_num of this ImapServerSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._seq_num

    @seq_num.setter
    def seq_num(self, seq_num):
        """Sets the seq_num of this ImapServerSearchOptions.


        :param seq_num: The seq_num of this ImapServerSearchOptions.  # noqa: E501
        :type: str
        """

        self._seq_num = seq_num

    @property
    def uid(self):
        """Gets the uid of this ImapServerSearchOptions.  # noqa: E501


        :return: The uid of this ImapServerSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._uid

    @uid.setter
    def uid(self, uid):
        """Sets the uid of this ImapServerSearchOptions.


        :param uid: The uid of this ImapServerSearchOptions.  # noqa: E501
        :type: str
        """

        self._uid = uid

    @property
    def since(self):
        """Gets the since of this ImapServerSearchOptions.  # noqa: E501


        :return: The since of this ImapServerSearchOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this ImapServerSearchOptions.


        :param since: The since of this ImapServerSearchOptions.  # noqa: E501
        :type: datetime
        """

        self._since = since

    @property
    def before(self):
        """Gets the before of this ImapServerSearchOptions.  # noqa: E501


        :return: The before of this ImapServerSearchOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this ImapServerSearchOptions.


        :param before: The before of this ImapServerSearchOptions.  # noqa: E501
        :type: datetime
        """

        self._before = before

    @property
    def sent_since(self):
        """Gets the sent_since of this ImapServerSearchOptions.  # noqa: E501


        :return: The sent_since of this ImapServerSearchOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._sent_since

    @sent_since.setter
    def sent_since(self, sent_since):
        """Sets the sent_since of this ImapServerSearchOptions.


        :param sent_since: The sent_since of this ImapServerSearchOptions.  # noqa: E501
        :type: datetime
        """

        self._sent_since = sent_since

    @property
    def sent_before(self):
        """Gets the sent_before of this ImapServerSearchOptions.  # noqa: E501


        :return: The sent_before of this ImapServerSearchOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._sent_before

    @sent_before.setter
    def sent_before(self, sent_before):
        """Sets the sent_before of this ImapServerSearchOptions.


        :param sent_before: The sent_before of this ImapServerSearchOptions.  # noqa: E501
        :type: datetime
        """

        self._sent_before = sent_before

    @property
    def header(self):
        """Gets the header of this ImapServerSearchOptions.  # noqa: E501


        :return: The header of this ImapServerSearchOptions.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._header

    @header.setter
    def header(self, header):
        """Sets the header of this ImapServerSearchOptions.


        :param header: The header of this ImapServerSearchOptions.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._header = header

    @property
    def body(self):
        """Gets the body of this ImapServerSearchOptions.  # noqa: E501


        :return: The body of this ImapServerSearchOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ImapServerSearchOptions.


        :param body: The body of this ImapServerSearchOptions.  # noqa: E501
        :type: list[str]
        """

        self._body = body

    @property
    def text(self):
        """Gets the text of this ImapServerSearchOptions.  # noqa: E501


        :return: The text of this ImapServerSearchOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this ImapServerSearchOptions.


        :param text: The text of this ImapServerSearchOptions.  # noqa: E501
        :type: list[str]
        """

        self._text = text

    @property
    def with_flags(self):
        """Gets the with_flags of this ImapServerSearchOptions.  # noqa: E501


        :return: The with_flags of this ImapServerSearchOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._with_flags

    @with_flags.setter
    def with_flags(self, with_flags):
        """Sets the with_flags of this ImapServerSearchOptions.


        :param with_flags: The with_flags of this ImapServerSearchOptions.  # noqa: E501
        :type: list[str]
        """

        self._with_flags = with_flags

    @property
    def without_flags(self):
        """Gets the without_flags of this ImapServerSearchOptions.  # noqa: E501


        :return: The without_flags of this ImapServerSearchOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._without_flags

    @without_flags.setter
    def without_flags(self, without_flags):
        """Sets the without_flags of this ImapServerSearchOptions.


        :param without_flags: The without_flags of this ImapServerSearchOptions.  # noqa: E501
        :type: list[str]
        """

        self._without_flags = without_flags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImapServerSearchOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImapServerSearchOptions):
            return True

        return self.to_dict() != other.to_dict()
